@@ -1,13 +1,15 @@
 package DBD::Cassandra::db;
 our $AUTHORITY = 'cpan:TVDW';
-$DBD::Cassandra::db::VERSION = '0.56_002'; # TRIAL
+$DBD::Cassandra::db::VERSION = '0.56_003'; # TRIAL
 
-$DBD::Cassandra::db::VERSION = '0.56002';# ABSTRACT: DBD::Cassandra database handle
+$DBD::Cassandra::db::VERSION = '0.56003';# ABSTRACT: DBD::Cassandra database handle
 
 use 5.010;
 use strict;
 use warnings;
 
+use Devel::GlobalDestruction;
+
 # This cargocult comes straight from DBI::DBD docs. No idea what it does.
 $DBD::Cassandra::db::imp_data_size = 0;
 
@@ -76,6 +78,8 @@ sub disconnect {
     my ($dbh)= @_;
     $dbh->STORE('Active', 0);
 
+    return if in_global_destruction;
+
     $dbh->{cass_client}->shutdown;
 }
 
@@ -105,7 +109,7 @@ DBD::Cassandra::db - DBD::Cassandra database handle
 
 =head1 VERSION
 
-version 0.56_002
+version 0.56_003
 
 =head1 AUTHOR
 
